<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>Acerca de Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Colaboradores</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Esta aplicación esta licenciada bajo los términos de la licencia Apache 2.0.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>y colaboradores:</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Sitio Web: %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Editor de Canales del Modo del Fixture</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Canales disponibles</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Canales del modo</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="123"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Extensión de archivo no reconocida: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Fixture loading failed</source>
        <translation>Fallo al cargar Fixture</translation>
    </message>
    <message>
        <location filename="app.cpp" line="148"/>
        <source>Unable to load fixture definition: </source>
        <translation>Imposible cargar definición de fixture:</translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <location filename="app.cpp" line="243"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="249"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="app.cpp" line="255"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;como...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="261"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="267"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>Index</source>
        <translation>Índice</translation>
    </message>
    <message>
        <location filename="app.cpp" line="274"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="279"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Sobre el Editor de Definiciones de Fixture...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="284"/>
        <source>About Qt...</source>
        <translation>Sobre QT...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="311"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="app.cpp" line="321"/>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <location filename="app.cpp" line="359"/>
        <source>Open a fixture definition</source>
        <translation>Abrir una definición de fixture</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Asistente de Capacidades</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Valores</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Valor DMX inicial</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Largo</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Cantidad de valores por capacidad</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Cantidad de capacidades a crear</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>El nombre comun para todas las capacidades. Utilice almohadilla (#) para crear números consecutivos.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation># Capacidades</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Muestra</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Lista de capacidades que serán creadas con estos parámetros</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="105"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Buscador de Documentos</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="127"/>
        <source>Backward</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Forward</source>
        <translation>Adelante</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Index</source>
        <translation>Índice</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>Close this window</source>
        <translation>Cerrar esta ventana</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Editor de Canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Se ha detectado superposición de capacidade. Por favor arreglar.&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation>Valor por defecto</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation>Preset</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Nombre de este canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation>Rol</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation>Color 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation>Color 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation>Valor 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation>Valor 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation>Vista Previa</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>El grupo al que pertenece este canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Grueso (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fino (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Capacidades</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Valor Mínimo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Valor Máximo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Quitar la capacidad seleccionada</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Asistente de Capacidades</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Editar canal: </translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Superposición de Valores</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Abrir archivo de Gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Imágenes de gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation>Recurso faltante</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation>Algunos gobos faltantes:

</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Algunas capacidades no pueden ser creadas debido a  una superposición de valores.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Editar Cabeza</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Editor de Modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Nombre del Modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="78"/>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="83"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="91"/>
        <source>Add channel(s) to this mode</source>
        <translation>Añadir canal(es) a este modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="111"/>
        <source>Remove the selected channel</source>
        <translation>Quitar el canal seleccionado</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="131"/>
        <source>Raise the selected channel</source>
        <translation>Subir el canal seleccionado</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="151"/>
        <source>Lower the selected channel</source>
        <translation>Bajar el canal seleccionado</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="185"/>
        <source>Heads</source>
        <translation>Cabezas</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="198"/>
        <source>Head</source>
        <translation>Cabeza</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Compose a new head</source>
        <translation>Componer una nueva cabeza</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="226"/>
        <source>Remove the selected head</source>
        <translation>Quitar la cabeza seleccionada</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="246"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Editar los canales que pertenecen a la cabeza seleccionada</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="266"/>
        <source>Raise the selected head</source>
        <translation>Subir la cabeza seleccionada</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="286"/>
        <source>Lower the selected head</source>
        <translation>Bajar la cabeza seleccionado</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="320"/>
        <source>Physical</source>
        <translation>Físico</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="330"/>
        <source>Use global settings</source>
        <translation>Usar ajustes globales</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="340"/>
        <source>Override global settings</source>
        <translation>Anular ajustes globales</translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Bombilla</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lúmenes</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Temperatura de Color (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Peso</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>Kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Largo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Profundidad</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation>Cabeza(s)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lente</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Grados Mínimos</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Grados Máximos</translation>
    </message>
    <message>
        <source>Prism faces</source>
        <translation type="vanished">Facetas del prisma</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Grados Max de Pan</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Grados Max de Tilt</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Eléctrico</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Consumo eléctrico</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>Conector DMX</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Copiar información física al portapapeles</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Pegar información física del portapapeles</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>El nombre del fabricante de este fixture (ej.:Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>El modelo de este fixture (ej.:MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>El tipo general de este fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="226"/>
        <source>LED Bar (Beams)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="235"/>
        <source>LED Bar (Pixels)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Nombre del autor de esta definición de fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Añadir a un canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Eliminar el canal seleccionado</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Editar el canal seleccionado</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Copiar el canal seleccionado al portapapeles</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Pegar el canal en el portapapeles a este fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Abrir/Cerrar todos los elementos de canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modos</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Cabezas</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Añadir un modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Eliminar el modo seleccionado</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Editar el modo seleccionado</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Crear una copia del modo seleccionado</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Abrir/Cerrar todos los elementos de modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation>En modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation>Añadir nuevo alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation>con</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation>reemplazar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation>Canal Base</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation>Override de canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation>Eliminar los alias seleccionados</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation>Físico</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>¿Desea guardar los cambios al fixture
&quot;%1&quot;
antes de cerrar?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Falta información importante</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Falta el nombre del fabricante.
No se puede guardar el fixture.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Falta el nombre del modelo de fixture.
No se puede guardar el fixture.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Fallo al guardar el Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Imposible salvar definiciones del fixture:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Guarda la definición del fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Nuevo Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="534"/>
        <source>Channel already exists</source>
        <translation>El canal ya existe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="535"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>¡Un canal con el nombre &quot;%1&quot; ya existe!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="541"/>
        <source>Channel has no name</source>
        <translation>El canal no tiene nombre</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="542"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>¡Tiene que dar al canal un nombre descriptivo!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>¿Está seguro que quiere quitar el canal: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="813"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>¿Está seguro que quiere quitar el modo: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="654"/>
        <location filename="fixtureeditor.cpp" line="689"/>
        <location filename="fixtureeditor.cpp" line="914"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="655"/>
        <location filename="fixtureeditor.cpp" line="691"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="656"/>
        <location filename="fixtureeditor.cpp" line="693"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="657"/>
        <location filename="fixtureeditor.cpp" line="695"/>
        <location filename="fixtureeditor.cpp" line="920"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="766"/>
        <location filename="fixtureeditor.cpp" line="775"/>
        <source>Unable to add mode</source>
        <translation>Imposible añadir modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="767"/>
        <source>Another mode by that name already exists</source>
        <translation>Otro modo con ese nombre ya existe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="776"/>
        <source>You must give a name to the mode</source>
        <translation>Necesita dar un nombre al modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="812"/>
        <source>Remove Mode</source>
        <translation>Eliminar modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="860"/>
        <source>Rename new mode</source>
        <translation>Renombrar el nuevo modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="861"/>
        <source>Give a unique name for the mode</source>
        <translation>Elija un nombre único para el modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="863"/>
        <source>Copy of %1</source>
        <translation>Copia de %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="873"/>
        <source>Invalid name</source>
        <translation>Nombre incorrecto</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Another mode by that name already exists.</source>
        <translation>Otro modo con ese nombre ya existe.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="917"/>
        <source>Clone</source>
        <translation>Clonar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="925"/>
        <source>Modes</source>
        <translation>Modos</translation>
    </message>
</context>
</TS>
